diff --git a/applications/utilities/postProcessing/dataConversion/foamToVTK/foamToVTK.C b/applications/utilities/postProcessing/dataConversion/foamToVTK/foamToVTK.C
index 101736d53a1511ab68d0e137d01298651d2a2def..9749c968a9d6b472422525036a623409f248fed8 100644
--- a/applications/utilities/postProcessing/dataConversion/foamToVTK/foamToVTK.C
+++ b/applications/utilities/postProcessing/dataConversion/foamToVTK/foamToVTK.C
@@ -168,8 +168,8 @@ Note
 labelList getSelectedPatches
 (
     const polyBoundaryMesh& patches,
-    const wordRes& whitelist,
-    const wordRes& blacklist
+    const wordRes& allow,
+    const wordRes& deny
 )
 {
     // Name-based selection
@@ -178,8 +178,8 @@ labelList getSelectedPatches
         stringListOps::findMatching
         (
             patches,
-            whitelist,
-            blacklist,
+            allow,
+            deny,
             nameOp<polyPatch>()
         )
     );
diff --git a/applications/utilities/surface/surfaceMeshExtract/surfaceMeshExtract.C b/applications/utilities/surface/surfaceMeshExtract/surfaceMeshExtract.C
index 2fff1bac66e9410bd2b6c9d52664252c9775a5ac..38b364c949dcc3a0ac808c3a0ecda8fefcb0b8f8 100644
--- a/applications/utilities/surface/surfaceMeshExtract/surfaceMeshExtract.C
+++ b/applications/utilities/surface/surfaceMeshExtract/surfaceMeshExtract.C
@@ -63,8 +63,8 @@ using namespace Foam;
 labelList getSelectedPatches
 (
     const polyBoundaryMesh& patches,
-    const wordRes& whitelist,
-    const wordRes& blacklist
+    const wordRes& allow,
+    const wordRes& deny
 )
 {
     // Name-based selection
@@ -73,8 +73,8 @@ labelList getSelectedPatches
         stringListOps::findMatching
         (
             patches,
-            whitelist,
-            blacklist,
+            allow,
+            deny,
             nameOp<polyPatch>()
         )
     );
diff --git a/applications/utilities/surface/surfaceSplitByPatch/surfaceSplitByPatch.C b/applications/utilities/surface/surfaceSplitByPatch/surfaceSplitByPatch.C
index 3f2d9d79a6290862c6cb217c610ac8493b8e22c2..65649dfd8a5fee7167a9b011416f0680b5ced2f2 100644
--- a/applications/utilities/surface/surfaceSplitByPatch/surfaceSplitByPatch.C
+++ b/applications/utilities/surface/surfaceSplitByPatch/surfaceSplitByPatch.C
@@ -120,7 +120,7 @@ int main(int argc, char *argv[])
             << nl << endl;
     }
 
-    // Identity if both whitelist and blacklist are empty
+    // Identity if both include/exclude lists are empty
     const labelList zoneIndices
     (
         stringListOps::findMatching
diff --git a/bin/tools/foamCreateModuleInclude b/bin/tools/foamCreateModuleInclude
index 39054fb23e77c5313876ca605a609355b3f2a013..1875a2f2c2e18f7331eaf997f9dee4642fd6e197 100755
--- a/bin/tools/foamCreateModuleInclude
+++ b/bin/tools/foamCreateModuleInclude
@@ -339,8 +339,8 @@ unset WM_DIR
 # Third-party cruft - only used for orig compilation
 # - as per spack installation
 
-# Blacklist '[A-Z].*_ARCH_PATH'
-# Whitelist 'MPI_ARCH_PATH'
+# Remove: '[A-Z].*_ARCH_PATH'
+# Keep:   'MPI_ARCH_PATH'
 
 for envname in $(env | sed -n -e 's/^\(.*ARCH_PATH\)=.*$/\1/p')
 do
diff --git a/src/OpenFOAM/primitives/strings/lists/stringListOpsTemplates.C b/src/OpenFOAM/primitives/strings/lists/stringListOpsTemplates.C
index 4de82c97e895ef519625c666fe5999e36b45eeef..5e3f6ddf4622566947761a31e167900e5e8e0021 100644
--- a/src/OpenFOAM/primitives/strings/lists/stringListOpsTemplates.C
+++ b/src/OpenFOAM/primitives/strings/lists/stringListOpsTemplates.C
@@ -6,7 +6,7 @@
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
     Copyright (C) 2011 OpenFOAM Foundation
-    Copyright (C) 2017 OpenCFD Ltd.
+    Copyright (C) 2017-2020 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -113,14 +113,14 @@ template<class StringListType, class AccessOp>
 Foam::labelList Foam::stringListOps::findMatching
 (
     const StringListType& input,
-    const wordRes& whitelist,
-    const wordRes& blacklist,
+    const wordRes& allow,
+    const wordRes& deny,
     AccessOp aop
 )
 {
     const label len = input.size();
 
-    if (whitelist.empty() && blacklist.empty())
+    if (allow.empty() && deny.empty())
     {
         return identity(len);
     }
@@ -134,20 +134,20 @@ Foam::labelList Foam::stringListOps::findMatching
 
         bool accept = false;
 
-        if (whitelist.size())
+        if (allow.size())
         {
-            const auto result = whitelist.matched(text);
+            const auto result = allow.matched(text);
 
             accept =
             (
                 result == wordRe::LITERAL
               ? true
-              : (result == wordRe::REGEX && !blacklist.match(text))
+              : (result == wordRe::REGEX && !deny.match(text))
             );
         }
         else
         {
-            accept = !blacklist.match(text);
+            accept = !deny.match(text);
         }
 
         if (accept)
diff --git a/src/conversion/ccm/reader/ccmSolutionTable.H b/src/conversion/ccm/reader/ccmSolutionTable.H
index 66fe7c38abced7e8858b9cee1909cec06588becd..f9343380c056b02cd582da77d048bf67ee423fae 100644
--- a/src/conversion/ccm/reader/ccmSolutionTable.H
+++ b/src/conversion/ccm/reader/ccmSolutionTable.H
@@ -5,7 +5,7 @@
     \\  /    A nd           | www.openfoam.com
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
-    Copyright (C) 2016-2018 OpenCFD Ltd.
+    Copyright (C) 2016-2020 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -65,9 +65,8 @@ public:
 
     // Constructors
 
-        //- Null construct
-        namesList()
-        {}
+        //- Default construct
+        namesList() = default;
 
 
     // Access
@@ -102,11 +101,11 @@ public:
         }
 
 
-        //- Return a list of names matching white-list and not in black-list
+        //- Return a list of names in allow-list and not in deny-list
         List<word> findNames
         (
-            const wordRes& white,
-            const wordRes& black = wordRes()
+            const wordRes& allow,
+            const wordRes& deny = wordRes()
         ) const
         {
             List<word> matched(SLList<T>::size());
@@ -116,16 +115,15 @@ public:
             {
                 const word& name = iter().name();
 
-                if (white.match(name) && !black.match(name))
+                if (allow.match(name) && !deny.match(name))
                 {
                     matched[matchi++] = name;
                 }
             }
-            matched.setSize(matchi);
+            matched.resize(matchi);
 
             return matched;
         }
-
 };
 
 
@@ -258,7 +256,6 @@ public:
 
             return os;
         }
-
 };
 
 
@@ -333,7 +330,6 @@ public:
 
             return os;
         }
-
 };
 
 
@@ -419,7 +415,6 @@ public:
 
             return os;
         }
-
 };
 
 
diff --git a/src/fileFormats/ensight/mesh/ensightMesh.H b/src/fileFormats/ensight/mesh/ensightMesh.H
index 1db242c65e5e9d929331b0caf946403eb23c534c..f85dddb5bf992a40c4045c73ec3a9aeec7c0dd40 100644
--- a/src/fileFormats/ensight/mesh/ensightMesh.H
+++ b/src/fileFormats/ensight/mesh/ensightMesh.H
@@ -303,10 +303,10 @@ public:
         //- Define patch selection matcher
         void patchSelection(List<wordRe>&& patterns);
 
-        //- Define patch selection blacklist
+        //- Define patch selection to exclude
         void patchExclude(const UList<wordRe>& patterns);
 
-        //- Define patch selection blacklist
+        //- Define patch selection to exclude
         void patchExclude(List<wordRe>&& patterns);
 
         //- Define faceZone selection matcher
diff --git a/src/functionObjects/field/ddt2/ddt2.C b/src/functionObjects/field/ddt2/ddt2.C
index f613f1197db145049f94533c17ac8629d5a3b495..1e01c761180986b540e0e804e8efc4a5ef3b8ebc 100644
--- a/src/functionObjects/field/ddt2/ddt2.C
+++ b/src/functionObjects/field/ddt2/ddt2.C
@@ -76,7 +76,7 @@ bool Foam::functionObjects::ddt2::accept(const word& fieldName) const
 {
     // check input vs possible result names
     // to avoid circular calculations
-    return !blacklist_.match(fieldName);
+    return !denyField_.match(fieldName);
 }
 
 
@@ -108,7 +108,7 @@ Foam::functionObjects::ddt2::ddt2
     fvMeshFunctionObject(name, runTime, dict),
     selectFields_(),
     resultName_(word::null),
-    blacklist_(),
+    denyField_(),
     results_(),
     mag_(dict.getOrDefault("mag", false))
 {
@@ -148,7 +148,7 @@ bool Foam::functionObjects::ddt2::read(const dictionary& dict)
      || checkFormatName(resultName_)
     )
     {
-        blacklist_.set
+        denyField_.set
         (
             string::quotemeta<regExp>
             (
@@ -159,7 +159,7 @@ bool Foam::functionObjects::ddt2::read(const dictionary& dict)
         return true;
     }
 
-    blacklist_.clear();
+    denyField_.clear();
     return false;
 }
 
diff --git a/src/functionObjects/field/ddt2/ddt2.H b/src/functionObjects/field/ddt2/ddt2.H
index 061f673222a3fd11851c94df3fcf3326dee9cafa..7cb8a734e2f0b91be9512b60b21595f56df5f204 100644
--- a/src/functionObjects/field/ddt2/ddt2.H
+++ b/src/functionObjects/field/ddt2/ddt2.H
@@ -137,7 +137,7 @@ class ddt2
         word resultName_;
 
         //- Avoid processing the same field twice
-        mutable regExp blacklist_;
+        mutable regExp denyField_;
 
         //- Hashed names of result fields
         wordHashSet results_;
diff --git a/src/surfMesh/MeshedSurface/MeshedSurface.H b/src/surfMesh/MeshedSurface/MeshedSurface.H
index 9e9e0e473fe08033f65221dfb3f2616f6a5204dd..5da16acea27e348f81f6ad57cb79479f89aab732 100644
--- a/src/surfMesh/MeshedSurface/MeshedSurface.H
+++ b/src/surfMesh/MeshedSurface/MeshedSurface.H
@@ -574,8 +574,10 @@ public:
 
         //- Return a new surface subsetted on the selected zone names
         //
-        //  \param[in] includeNames the zone names to white-list
-        //  \param[in] excludeNames the zone names to black-list
+        //  \param[in] includeNames surface zone names to include
+        //  \param[in] excludeNames surface zone names to exclude
+        //
+        //  \see Foam::stringListOps::findMatching for details about matching
         MeshedSurface subsetMesh
         (
             const wordRes& includeNames,
diff --git a/src/surfMesh/surfaceFormats/surfaceFormatsCore.C b/src/surfMesh/surfaceFormats/surfaceFormatsCore.C
index 83d2c159624e8b28d9941ab4a0c08cbcedf976bf..7b852cb3c1689fe9f201a0f395d29e220f6cb760 100644
--- a/src/surfMesh/surfaceFormats/surfaceFormatsCore.C
+++ b/src/surfMesh/surfaceFormats/surfaceFormatsCore.C
@@ -59,16 +59,16 @@ Foam::string Foam::fileFormats::surfaceFormatsCore::getLineNoComment
 Foam::labelList Foam::fileFormats::surfaceFormatsCore::getSelectedPatches
 (
     const surfZoneList& patches,
-    const wordRes& whitelist,
-    const wordRes& blacklist
+    const wordRes& allow,
+    const wordRes& deny
 )
 {
     return
         stringListOps::findMatching
         (
             patches,
-            whitelist,
-            blacklist,
+            allow,
+            deny,
             nameOp<surfZone>()
         );
 }
diff --git a/src/surfMesh/surfaceFormats/surfaceFormatsCore.H b/src/surfMesh/surfaceFormats/surfaceFormatsCore.H
index 79d9afe12f7e4f66fdceeab1ea55d0fdd97dc7a2..e023bb14806deeaee78ac0e3ac44ae3c9e481536 100644
--- a/src/surfMesh/surfaceFormats/surfaceFormatsCore.H
+++ b/src/surfMesh/surfaceFormats/surfaceFormatsCore.H
@@ -90,14 +90,14 @@ protected:
         }
 
         //- Return ids for zone/patch that match by name.
-        //  Uses a combination of whitelist and blacklist.
+        //  Uses a combination of allow and deny lists.
         //
-        //  See Foam::stringListOps::findMatching
+        //  \see Foam::stringListOps::findMatching for details about matching
         static labelList getSelectedPatches
         (
             const surfZoneList& patches,
-            const wordRes& whitelist,
-            const wordRes& blacklist = wordRes()
+            const wordRes& allow,
+            const wordRes& deny = wordRes()
         );
 
 
diff --git a/src/surfMesh/triSurface/triSurface.H b/src/surfMesh/triSurface/triSurface.H
index b920abc69a839bb286288decd8bde18e5916a4ca..695f6fbe6818f0358fe021ff5b1e4e53858d67e8 100644
--- a/src/surfMesh/triSurface/triSurface.H
+++ b/src/surfMesh/triSurface/triSurface.H
@@ -548,8 +548,10 @@ public:
 
         //- Return a new surface subsetted on the selected patch names
         //
-        //  \param[in] includeNames the patch names to white-list
-        //  \param[in] excludeNames the patch names to black-list
+        //  \param[in] includeNames surface patch names to include
+        //  \param[in] excludeNames surface patch names to exclude
+        //
+        //  \see Foam::stringListOps::findMatching for details about matching
         triSurface subsetMesh
         (
             const wordRes& includeNames,
diff --git a/src/OpenFOAM/primitives/strings/lists/stringListOps.H b/src/OpenFOAM/primitives/strings/lists/stringListOps.H
index 9e60bbdd196dfc12155a09db3fd4058784d1d9aa..e4c1d56d8f295aac78284ce1576b7b3054deed5a 100644
--- a/src/OpenFOAM/primitives/strings/lists/stringListOps.H
+++ b/src/OpenFOAM/primitives/strings/lists/stringListOps.H
@@ -349,16 +349,16 @@ struct foundOp
 
 
 //- Return ids for items with matching names.
-//  Uses a combination of whitelist and blacklist.
+//  Uses a combination of allow and deny lists
 //
 //  An empty whitelist accepts everything that is not blacklisted.
 //  A regex match is trumped by a literal match.
 //
 //  Eg,
 //  \verbatim
 //     input:  ( abc apple wall wall1 wall2 )
 //     whitelist:  ( abc  def  "wall.*" )
 //     blacklist:  ( "[ab].*"  wall )
 //
 //     result:  (abc wall1 wall2)
 //  \endverbatim
@@ -368,8 +368,8 @@ template<class StringListType, class AccessOp = noOp>
 labelList findMatching
 (
     const StringListType& input,
-    const wordRes& whitelist,
-    const wordRes& blacklist = wordRes(),
+    const wordRes& allow,
+    const wordRes& deny = wordRes(),
     AccessOp aop = noOp()
 );
 
@@ -349,16 +349,16 @@ struct foundOp
 //
-//  An empty whitelist accepts everything that is not blacklisted.
-//  A regex match is trumped by a literal match.
+//  An empty 'allow' list accepts everything not in the 'deny' list.
+//  A literal match has higher priority over a regex match.
 //
 //  Eg,
@@ -349,16 +349,16 @@ struct foundOp
 //  \verbatim
 //     input:  ( abc apple wall wall1 wall2 )
-//     whitelist:  ( abc  def  "wall.*" )
-//     blacklist:  ( "[ab].*"  wall )
+//     allow:  ( abc  def  "wall.*" )
+//     deny:   ( "[ab].*"  wall )
 //
 //     result:  (abc wall1 wall2)